@@ -3,7 +3,7 @@ from pathlib import Path
 
 
 def output_midsv(TEMPDIR, path_sam, DICT_ALLELE):
-    name_fasta = path_sam.stem.split("_")[1]
+    name_fasta = path_sam.stem.split("_")[-1]
     if name_fasta not in set(DICT_ALLELE.keys()):
         return
     sam = midsv.read_sam(path_sam)
